{% extends "rest_framework/base.html" %}
{% load static %}

{% block title %}
    NSoT | REST API
{% endblock %}

{% block bootstrap_theme %}
    {% include "ui/media.html" %}
{% endblock %}

{% block navbar %}
    <div class="container-fluid" ng-app="nsotApp">
        {% include "ui/menu.html" %}
    </div>
{% endblock %}

{% block script %}
    {% include "ui/scripts.html" %}
    <script src="{% static "rest_framework/js/ajax-form.js" %}"></script>
    <script src="{% static "rest_framework/js/csrf.js" %}"></script>
    <script src="{% static "rest_framework/js/prettify-min.js" %}"></script>
    <script src="{% static "rest_framework/js/default.js" %}"></script>
    <script>
        $(document).ready(function() {
            $('form').ajaxForm();
        });
    </script>

{% endblock %} 
