<!DOCTYPE html>
{% autoescape on %}
<html lang="en" ng-app="nsotApp">
    <head>
        <title>NSoT</title>

        {% include "ui/media.html" %}
    </head>
    <body>
        <div class="container-fluid">
            {% include "ui/menu.html" %}

            <div class="row">
                <div class="col-sm-12 col-sm-offset-0">
                    <div id="content">
                        <ng-view></ng-view>
                    </div>
                </div>
            </div>
        </div>

        {% include "ui/scripts.html" %}
    </body>
</html>
{% endautoescape %}
