<link href="/static/build/vendor/bootstrap/dist/css/bootstrap.min.css"
      rel="stylesheet"
      media="screen">
<link href="/static/build/vendor/ng-tags-input/build/ng-tags-input.min.css"
      rel="stylesheet"
      media="screen">
<link href="/static/build/vendor/ng-tags-input/build/ng-tags-input.bootstrap.min.css"
      rel="stylesheet"
      media="screen">
<link href="/static/build/vendor/font-awesome/css/font-awesome.min.css"
      rel="stylesheet"
      media="screen">
<link href="/static/build/style/nsot.min.css"
      rel="stylesheet"
      media="screen">
<link href="/static/build/vendor/angular-chart.js/dist/angular-chart.min.css"
      rel="stylesheet"
      media="screen">
<link href="/static/build/images/favicon/favicon.ico"
      type="image/x-icon"
      rel="icon">
