{% extends "rest_framework/login_base.html" %}
{% load static %}

{% block title %}
    NSoT | Login
{% endblock %}

{% block bootstrap_theme %}
    {% include "ui/media.html" %}
{% endblock %}

{% block branding %}
    <h3 style="margin: 0 0 20px;">Network Source of Truth</h3>
{% endblock %}
